@@ -23,9 +23,17 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
+#include "actions.h"
+#include "common.h"
+
+#include <gio/gio.h>
+#include <gtk/gtk.h>
+#include <libxfce4ui/libxfce4ui.h>
+#include <libxfce4util/libxfce4util.h>
+
 #ifdef HAVE_LOCALE_H
 #include <locale.h>
 #endif
@@ -34,26 +42,17 @@
 #include <string.h>
 #endif
 
-#include <gio/gio.h>
-#include <gtk/gtk.h>
-#include <libxfce4ui/libxfce4ui.h>
-#include <libxfce4util/libxfce4util.h>
-
-#include "common.h"
-
-#include "actions.h"
-
 /*
  * GObject declarations
  */
 
 struct _ClipmanActionsPrivate
 {
-  GFile                *file;
-  GFileMonitor         *file_monitor;
-  GSList               *entries;
-  GtkWidget            *menu;
-  gboolean              skip_action_on_key_down;
+  GFile *file;
+  GFileMonitor *file_monitor;
+  GSList *entries;
+  GtkWidget *menu;
+  gboolean skip_action_on_key_down;
 };
 
 G_DEFINE_TYPE_WITH_PRIVATE (ClipmanActions, clipman_actions, G_TYPE_OBJECT)
@@ -63,59 +62,70 @@ enum
   SKIP_ACTION_ON_KEY_DOWN = 1,
 };
 
-static void             clipman_actions_finalize            (GObject *object);
-static void             clipman_actions_set_property        (GObject *object,
-                                                             guint property_id,
-                                                             const GValue *value,
-                                                             GParamSpec *pspec);
-static void             clipman_actions_get_property        (GObject *object,
-                                                             guint property_id,
-                                                             GValue *value,
-                                                             GParamSpec *pspec);
+static void
+clipman_actions_finalize (GObject *object);
+static void
+clipman_actions_set_property (GObject *object,
+                              guint property_id,
+                              const GValue *value,
+                              GParamSpec *pspec);
+static void
+clipman_actions_get_property (GObject *object,
+                              guint property_id,
+                              GValue *value,
+                              GParamSpec *pspec);
 
 /*
  * Misc functions declarations
  */
 
-static void            _clipman_actions_free_list           (ClipmanActions *actions);
-static gint           __clipman_actions_entry_compare       (gpointer a,
-                                                             gpointer b);
-static gint           __clipman_actions_entry_compare_name  (gpointer a,
-                                                             gpointer b);
-static void           __clipman_actions_entry_free          (ClipmanActionsEntry *entry);
+static void
+_clipman_actions_free_list (ClipmanActions *actions);
+static gint
+__clipman_actions_entry_compare (gconstpointer a,
+                                 gconstpointer b);
+static gint
+__clipman_actions_entry_compare_name (gconstpointer a,
+                                      gconstpointer b);
+static void
+__clipman_actions_entry_free (ClipmanActionsEntry *entry);
 
 /*
  * Callbacks declarations
  */
 
-static void             cb_entry_activated                  (GtkMenuItem *mi,
-                                                             gpointer user_data);
-static void             cb_file_changed                     (ClipmanActions *actions,
-                                                             GFile *file,
-                                                             GFile *other_file,
-                                                             GFileMonitorEvent event_type);
+static void
+cb_entry_activated (GtkMenuItem *mi,
+                    gpointer user_data);
+static void
+cb_file_changed (ClipmanActions *actions,
+                 GFile *file,
+                 GFile *other_file,
+                 GFileMonitorEvent event_type);
 /*
  * XML Parser declarations
  */
 
-static void             start_element_handler               (GMarkupParseContext *context,
-                                                             const gchar *element_name,
-                                                             const gchar **attribute_names,
-                                                             const gchar **attribute_values,
-                                                             gpointer user_data,
-                                                             GError **error);
-static void             end_element_handler                 (GMarkupParseContext *context,
-                                                             const gchar *element_name,
-                                                             gpointer user_data,
-                                                             GError **error);
-static void             text_handler                        (GMarkupParseContext *context,
-                                                             const gchar *text,
-                                                             gsize text_len,
-                                                             gpointer user_data,
-                                                             GError **error);
+static void
+start_element_handler (GMarkupParseContext *context,
+                       const gchar *element_name,
+                       const gchar **attribute_names,
+                       const gchar **attribute_values,
+                       gpointer user_data,
+                       GError **error);
+static void
+end_element_handler (GMarkupParseContext *context,
+                     const gchar *element_name,
+                     gpointer user_data,
+                     GError **error);
+static void
+text_handler (GMarkupParseContext *context,
+              const gchar *text,
+              gsize text_len,
+              gpointer user_data,
+              GError **error);
 
-static GMarkupParser markup_parser =
-{
+static GMarkupParser markup_parser = {
   start_element_handler,
   end_element_handler,
   text_handler,
@@ -319,7 +329,7 @@ text_handler (GMarkupParseContext *context,
       break;
 
     case GROUP:
-      parser->group = (gint)g_strtod (text, NULL);
+      parser->group = (gint) g_strtod (text, NULL);
       break;
 
     case COMMAND_NAME:
@@ -386,21 +396,21 @@ cb_file_changed (ClipmanActions *actions,
                  GFileMonitorEvent event_type)
 {
   static GSource *source = NULL;
-  guint           source_id;
+  guint source_id;
 
   if (event_type == G_FILE_MONITOR_EVENT_CHANGES_DONE_HINT)
     {
       /* drop the previous timer source */
       if (source != NULL)
         {
-          if (! g_source_is_destroyed (source))
+          if (!g_source_is_destroyed (source))
             g_source_destroy (source);
 
           g_source_unref (source);
           source = NULL;
         }
 
-      source_id = g_timeout_add_seconds (1, (GSourceFunc)timeout_file_changed, actions);
+      source_id = g_timeout_add_seconds (1, timeout_file_changed, actions);
 
       /* retrieve the timer source and increase its ref count to test its destruction next time */
       source = g_main_context_find_source_by_id (NULL, source_id);
@@ -415,16 +425,13 @@ cb_file_changed (ClipmanActions *actions,
 static void
 _clipman_actions_free_list (ClipmanActions *actions)
 {
-  GSList *l;
-  for (l = actions->priv->entries; l != NULL; l = l->next)
-    __clipman_actions_entry_free (l->data);
-  g_slist_free (actions->priv->entries);
+  g_slist_free_full (actions->priv->entries, (GDestroyNotify) __clipman_actions_entry_free);
   actions->priv->entries = NULL;
 }
 
 static gint
-__clipman_actions_entry_compare (gpointer a,
-                                 gpointer b)
+__clipman_actions_entry_compare (gconstpointer a,
+                                 gconstpointer b)
 {
   const ClipmanActionsEntry *entrya = a;
   const ClipmanActionsEntry *entryb = b;
@@ -432,8 +439,8 @@ __clipman_actions_entry_compare (gpointer a,
 }
 
 static gint
-__clipman_actions_entry_compare_name (gpointer a,
-                                      gpointer b)
+__clipman_actions_entry_compare_name (gconstpointer a,
+                                      gconstpointer b)
 {
   const ClipmanActionsEntry *entry = a;
   const char *name = b;
@@ -491,14 +498,14 @@ clipman_actions_add (ClipmanActions *actions,
   g_return_val_if_fail (command_name != NULL, FALSE);
   g_return_val_if_fail (command != NULL, FALSE);
 
-  l = g_slist_find_custom (actions->priv->entries, action_name, (GCompareFunc)__clipman_actions_entry_compare_name);
+  l = g_slist_find_custom (actions->priv->entries, action_name, __clipman_actions_entry_compare_name);
 
   /* Add a new entry to the list */
   if (l == NULL)
     {
       /* Validate the regex */
       regex_anchored = g_strdup_printf ("%s$", regex);
-      _regex = g_regex_new (regex_anchored, G_REGEX_CASELESS|G_REGEX_ANCHORED, 0, NULL);
+      _regex = g_regex_new (regex_anchored, G_REGEX_CASELESS | G_REGEX_ANCHORED, 0, NULL);
       g_free (regex_anchored);
       if (_regex == NULL)
         return FALSE;
@@ -510,11 +517,10 @@ clipman_actions_add (ClipmanActions *actions,
       entry->pattern = g_strdup (regex);
       entry->regex = _regex;
       entry->group = 0;
-      entry->commands = g_hash_table_new_full ((GHashFunc)g_str_hash, (GEqualFunc)g_str_equal,
-                                               (GDestroyNotify)g_free, (GDestroyNotify)g_free);
+      entry->commands = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_free);
       g_hash_table_insert (entry->commands, g_strdup (command_name), g_strdup (command));
 
-      actions->priv->entries = g_slist_insert_sorted (actions->priv->entries, entry, (GCompareFunc)__clipman_actions_entry_compare);
+      actions->priv->entries = g_slist_insert_sorted (actions->priv->entries, entry, __clipman_actions_entry_compare);
       return TRUE;
     }
 
@@ -542,7 +548,7 @@ clipman_actions_remove (ClipmanActions *actions,
   ClipmanActionsEntry *entry;
   GSList *l;
 
-  l = g_slist_find_custom (actions->priv->entries, action_name, (GCompareFunc)__clipman_actions_entry_compare_name);
+  l = g_slist_find_custom (actions->priv->entries, action_name, __clipman_actions_entry_compare_name);
   if (l == NULL)
     {
       g_warning ("No corresponding entry `%s'", action_name);
@@ -579,7 +585,7 @@ clipman_actions_remove_command (ClipmanActions *actions,
   GSList *l;
   gboolean found;
 
-  l = g_slist_find_custom (actions->priv->entries, action_name, (GCompareFunc)__clipman_actions_entry_compare_name);
+  l = g_slist_find_custom (actions->priv->entries, action_name, __clipman_actions_entry_compare_name);
   if (l == NULL)
     {
       g_warning ("No corresponding entry `%s'", action_name);
@@ -621,7 +627,7 @@ clipman_actions_set_group (ClipmanActions *actions,
   ClipmanActionsEntry *entry;
   GSList *l;
 
-  l = g_slist_find_custom (actions->priv->entries, action_name, (GCompareFunc)__clipman_actions_entry_compare_name);
+  l = g_slist_find_custom (actions->priv->entries, action_name, __clipman_actions_entry_compare_name);
   if (l == NULL)
     {
       g_warning ("No corresponding entry `%s'", action_name);
@@ -700,11 +706,11 @@ clipman_actions_match_with_menu (ClipmanActions *actions,
   GtkWidget *mi;
   GSList *l, *entries;
   GdkModifierType state = 0;
-  GdkDisplay* display = gdk_display_get_default ();
+  GdkDisplay *display = gdk_display_get_default ();
   GdkSeat *seat = gdk_display_get_default_seat (display);
   GdkDevice *device = gdk_seat_get_pointer (seat);
-  GdkScreen* screen = gdk_screen_get_default ();
-  GdkWindow * root_win = gdk_screen_get_root_window (screen);
+  GdkScreen *screen = gdk_screen_get_default ();
+  GdkWindow *root_win = gdk_screen_get_root_window (screen);
   GdkEvent *event;
 
   if (group == ACTION_GROUP_SELECTION)
@@ -737,7 +743,7 @@ clipman_actions_match_with_menu (ClipmanActions *actions,
     }
 
   actions->priv->menu = gtk_menu_new ();
-  g_object_set_data_full (G_OBJECT (actions->priv->menu), "text", g_strdup (text), (GDestroyNotify)g_free);
+  g_object_set_data_full (G_OBJECT (actions->priv->menu), "text", g_strdup (text), g_free);
 
   for (l = entries; l != NULL; l = l->next)
     {
@@ -750,20 +756,20 @@ clipman_actions_match_with_menu (ClipmanActions *actions,
       mi = gtk_separator_menu_item_new ();
       gtk_container_add (GTK_CONTAINER (actions->priv->menu), mi);
 
-        {
-          GHashTableIter iter;
-          gpointer key, value;
-          g_hash_table_iter_init (&iter, entry->commands);
-          while (g_hash_table_iter_next (&iter, &key, &value))
-            {
-              mi = gtk_menu_item_new_with_label ((const gchar *)key);
-              g_object_set_data (G_OBJECT (mi), "text", g_object_get_data (G_OBJECT (actions->priv->menu), "text"));
-              g_object_set_data (G_OBJECT (mi), "command", value);
-              g_object_set_data (G_OBJECT (mi), "regex", entry->regex);
-              gtk_container_add (GTK_CONTAINER (actions->priv->menu), mi);
-              g_signal_connect (mi, "activate", G_CALLBACK (cb_entry_activated), NULL);
-            }
-        }
+      {
+        GHashTableIter iter;
+        gpointer key, value;
+        g_hash_table_iter_init (&iter, entry->commands);
+        while (g_hash_table_iter_next (&iter, &key, &value))
+          {
+            mi = gtk_menu_item_new_with_label ((const gchar *) key);
+            g_object_set_data (G_OBJECT (mi), "text", g_object_get_data (G_OBJECT (actions->priv->menu), "text"));
+            g_object_set_data (G_OBJECT (mi), "command", value);
+            g_object_set_data (G_OBJECT (mi), "regex", entry->regex);
+            gtk_container_add (GTK_CONTAINER (actions->priv->menu), mi);
+            g_signal_connect (mi, "activate", G_CALLBACK (cb_entry_activated), NULL);
+          }
+      }
 
       mi = gtk_separator_menu_item_new ();
       gtk_container_add (GTK_CONTAINER (actions->priv->menu), mi);
@@ -774,10 +780,10 @@ clipman_actions_match_with_menu (ClipmanActions *actions,
 
   gtk_widget_show_all (actions->priv->menu);
 
-  if(!gtk_widget_has_grab(actions->priv->menu))
-  {
-    gtk_grab_add(actions->priv->menu);
-  }
+  if (!gtk_widget_has_grab (actions->priv->menu))
+    {
+      gtk_grab_add (actions->priv->menu);
+    }
 
   event = gdk_event_new (GDK_BUTTON_PRESS);
   event->button.window = g_object_ref (root_win);
@@ -803,7 +809,7 @@ clipman_actions_load (ClipmanActions *actions)
   GMarkupParseContext *context;
   EntryParser *parser;
 
-  load = g_file_load_contents (actions->priv->file, NULL, &data, (gsize*)&size, NULL, NULL);
+  load = g_file_load_contents (actions->priv->file, NULL, &data, (gsize *) &size, NULL, NULL);
 
   if (!load)
     {
@@ -814,8 +820,8 @@ clipman_actions_load (ClipmanActions *actions)
       dir = NULL;
 
       /* Load from system wide file */
-      filename = g_strdup (SYSCONFDIR"/xdg/xfce4/panel/xfce4-clipman-actions.xml");
-      load = g_file_get_contents (filename, &data, (gsize*)&size, NULL);
+      filename = g_strdup (SYSCONFDIR "/xdg/xfce4/panel/xfce4-clipman-actions.xml");
+      load = g_file_get_contents (filename, &data, (gsize *) &size, NULL);
       g_free (filename);
     }
 
@@ -876,25 +882,25 @@ clipman_actions_save (ClipmanActions *actions)
 
       g_string_append (output, "\t\t<commands>\n");
 
-        {
-          GHashTableIter iter;
-          gpointer key, value;
-          g_hash_table_iter_init (&iter, entry->commands);
-          while (g_hash_table_iter_next (&iter, &key, &value))
-            {
-              g_string_append (output, "\t\t\t<command>\n");
+      {
+        GHashTableIter iter;
+        gpointer key, value;
+        g_hash_table_iter_init (&iter, entry->commands);
+        while (g_hash_table_iter_next (&iter, &key, &value))
+          {
+            g_string_append (output, "\t\t\t<command>\n");
 
-              tmp = g_markup_escape_text (key, -1);
-              g_string_append_printf (output, "\t\t\t\t<name>%s</name>\n", tmp);
-              g_free (tmp);
+            tmp = g_markup_escape_text (key, -1);
+            g_string_append_printf (output, "\t\t\t\t<name>%s</name>\n", tmp);
+            g_free (tmp);
 
-              tmp = g_markup_escape_text (value, -1);
-              g_string_append_printf (output, "\t\t\t\t<exec>%s</exec>\n", tmp);
-              g_free (tmp);
+            tmp = g_markup_escape_text (value, -1);
+            g_string_append_printf (output, "\t\t\t\t<exec>%s</exec>\n", tmp);
+            g_free (tmp);
 
-              g_string_append (output, "\t\t\t</command>\n");
-            }
-        }
+            g_string_append (output, "\t\t\t</command>\n");
+          }
+      }
 
       g_string_append (output, "\t\t</commands>\n");
 
@@ -925,7 +931,7 @@ clipman_actions_get (void)
   if (singleton == NULL)
     {
       singleton = g_object_new (CLIPMAN_TYPE_ACTIONS, NULL);
-      g_object_add_weak_pointer (G_OBJECT (singleton), (gpointer)&singleton);
+      g_object_add_weak_pointer (G_OBJECT (singleton), (gpointer) &singleton);
     }
   else
     g_object_ref (G_OBJECT (singleton));
@@ -952,7 +958,7 @@ clipman_actions_class_init (ClipmanActionsClass *klass)
                                                          "SkipActionOnKeyDown",
                                                          "Skip the action if the Control key is pressed down",
                                                          DEFAULT_SKIP_ACTION_ON_KEY_DOWN,
-                                                         G_PARAM_CONSTRUCT|G_PARAM_READWRITE));
+                                                         G_PARAM_CONSTRUCT | G_PARAM_READWRITE));
 }
 
 static void
@@ -979,9 +985,12 @@ static void
 clipman_actions_finalize (GObject *object)
 {
   ClipmanActions *actions = CLIPMAN_ACTIONS (object);
+
   _clipman_actions_free_list (actions);
   g_object_unref (actions->priv->file_monitor);
   g_object_unref (actions->priv->file);
+
+  G_OBJECT_CLASS (clipman_actions_parent_class)->finalize (object);
 }
 
 static void
